#!perl
#------------------------------------------------------------------------------
# Copyright (c) Perforce Software, Inc., 2007-2014. All rights reserved
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1  Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# 2.  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE
# SOFTWARE, INC. BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#------------------------------------------------------------------------------

#
# Verifies a depot path one directory at a time.
#
# The required arguments are:
# 1. Depot path to start searching in.  Must end with a trailing '/...'.
# 2. Perforce command string
#

# subs
sub verifydirs($$);

# parse command line: 
# - depot path to search
# - perforce command string
if($#ARGV ne 1) {
    die "\n\nUsage: p4verify.pl <depot path for search> <p4 cmd string>\n\n";
}
my $depot_dir = $ARGV[0];
if($depot_dir !~ /\/\.\.\.$/) {
    die "\n\nDepot path for search must end with '/...'.\n\n";
}
my $p4 = $ARGV[1];

# run 'p4 verify' on each directory in the tree
verifydirs(substr($depot_dir, 0, -4), $p4);

exit(0);

# 
# verifydirs: Runs p4 verify on a dir and all sub-dirs
#
sub verifydirs($$) { 
    my ($dir,$p4) = @_;
    $dir = $dir . '/*';
    my $verify_cmd = $p4 . ' -s verify -q "' . $dir . '"';
    my $verify_list = `$verify_cmd 2>&1`;
    if($verify_list !~ /no such file/) {
        print $verify_list;
    }

    my $dirlist_cmd = $p4 . ' dirs "' . $dir . '"';
    my $dirlist = `$dirlist_cmd 2>&1`;
    if($dirlist !~ /no such file/) {
        foreach my $adir (split(/\n/, $dirlist)) {
            next unless $adir =~ /\/\//;
            verifydirs($adir,$p4);
        }
    }
} # end verifydirs
